@@ -43,6 +43,7 @@ from kiosk_client.job import Job
 from kiosk_client.utils import iter_image_files
 from kiosk_client.utils import sleep
 from kiosk_client.utils import strip_bucket_prefix
+from kiosk_client.utils import get_download_path
 from kiosk_client import settings
 
 from kiosk_client.cost import CostGetter
@@ -113,6 +114,14 @@ class JobManager(object):
         self.download_results = kwargs.get('download_results', True)
         self.calculate_cost = kwargs.get('calculate_cost', False)
 
+        self.output_dir = kwargs.get('output_dir', get_download_path())
+        if not os.path.isdir(self.output_dir):
+            raise ValueError('Invalid value for output_dir,'
+                             ' %s is not a directory.' % self.output_dir)
+        if not os.access(self.output_dir, os.W_OK):
+            raise ValueError('Invalid value for output_dir,'
+                             ' %s is not writable.' % self.output_dir)
+
         # initializing cost estimation workflow
         self.cost_getter = CostGetter()
 
@@ -179,7 +188,8 @@ class JobManager(object):
                    update_interval=self.update_interval,
                    download_results=self.download_results,
                    expire_time=self.expire_time,
-                   pool=self.pool)
+                   pool=self.pool,
+                   output_dir=self.output_dir)
 
     def get_completed_job_count(self):
         created, complete, failed, expired = 0, 0, 0, 0
@@ -266,7 +276,7 @@ class JobManager(object):
         output_filepath = '{}{}jobs_{}delay_{}.json'.format(
             '{}gpu_'.format(settings.NUM_GPUS) if settings.NUM_GPUS else '',
             len(self.all_jobs), self.start_delay, uuid.uuid4().hex)
-        output_filepath = os.path.join(settings.OUTPUT_DIR, output_filepath)
+        output_filepath = os.path.join(self.output_dir, output_filepath)
 
         with open(output_filepath, 'w') as jsonfile:
             json.dump(jsondata, jsonfile, indent=4)
