@@ -57,7 +57,7 @@ class TestJobManager(object):
     def monkeypatch(self, monkeypatch):
         monkeypatch.setattr(requests, 'get', dummy_ssl_redirect)
 
-    def test_init(self):
+    def test_init(self, mocker):
         mgr = manager.JobManager(
             job_type='job',
             host='localhost',
@@ -95,6 +95,24 @@ class TestJobManager(object):
                 model='m:0',
                 data_scale='1',
                 data_label='1.3')
+        # test bad output_dir value
+        with pytest.raises(ValueError):
+            mgr = manager.JobManager(
+                job_type='job',
+                host='localhost',
+                model='m:0',
+                data_scale='1',
+                data_label='1',
+                output_dir='not_a_directory')
+        # output_dir should be writable
+        mocker.patch('os.access', return_value=False)
+        with pytest.raises(ValueError):
+            mgr = manager.JobManager(
+                job_type='job',
+                host='localhost',
+                model='m:0',
+                data_scale='1',
+                data_label='1')
 
     def test__get_host(self, mocker):
         host = 'example.com'
@@ -167,7 +185,6 @@ class TestJobManager(object):
         assert mgr.get_completed_job_count() == 0
 
     def test_summarize(self, tmpdir):
-
         # pylint: disable=unused-argument
         def fake_upload_file(filepath, hash_filename, prefix):
             return filepath
@@ -181,11 +198,10 @@ class TestJobManager(object):
         def fake_download_file_bad(url, dest):
             return 1 / 0
 
-        settings.OUTPUT_DIR = str(tmpdir)
-
         mgr = manager.JobManager(host='localhost', job_type='job',
                                  upload_results=True,
-                                 calculate_cost=True)
+                                 calculate_cost=True,
+                                 output_dir=str(tmpdir))
 
         fakejson = lambda: {'output_url': 'example.com/json.txt'}
         mgr.all_jobs = [Bunch(output_url='example.com/a.txt', json=fakejson),
